@@ -1,12 +1,12 @@
 # encoding: utf-8
 
+import logging
 import logging_helper
 from configurationutil import Configuration, cfg_params
 from .._metadata import __version__, __authorshort__, __module_name__
 from .._exceptions import NoActiveRecordForHost
 from ..resources import templates, schema
 
-logging = logging_helper.setup_logging()
 
 # Register Config details (These are expected to be overwritten by an importing app)
 cfg_params.APP_NAME = __module_name__
