@@ -1,16 +1,14 @@
 # encoding: utf-8
 
-import sys
 import socket
 import dns.resolver
 from dns.message import from_wire, make_response
 from dns.rcode import NXDOMAIN
-import logging_helper
+import logging
 from ipaddress import IPv4Address, IPv4Network, AddressValueError, ip_address
 from .config import dns_lookup, dns_forwarders
 from ._exceptions import DNSQueryFailed
 
-logging = logging_helper.setup_logging()
 
 '81a70100000100000000000009676574706f636b65740363646e076d6f7a696c6c61036e657400001c0001'
 "\x81\xa7\x01\x00\x00\x01\x00\x00\x00\x00\x00\x00\x09\x67\x65\x74" \
@@ -77,8 +75,8 @@ class DNSQuery(object):
     def resolve(self):
 
         name = self.question.name
-        self.message = u'DNS ({dns}): {name}: ?.?.?.?. '.format(dns=self.interface,
-                                                                name=self.question.name)
+        self.message = u'DNS ({ip_address}): {name}: ?.?.?.?. '.format(ip_address=self.client_address[0],
+                                                                       name=name)
 
         # Handle reverse lookups
         if u'.in-addr.arpa.' in name:
@@ -237,7 +235,7 @@ class DNSQuery(object):
                                                                         interface=self.interface,
                                                                         address=address))
 
-        except (IndexError, dns.exception.DNSException, dns.exception.Timeout) as err:
+        except (IndexError, dns.exception.DNSException, dns.exception.Timeout, AttributeError) as err:
             self.message += u'(dns.resolver failed). '
             raise DNSQueryFailed(u'dns.resolver failed: {err}'.format(err=err))
 
