@@ -1,13 +1,10 @@
 # encoding: utf-8
 
-import logging_helper
 from uiutil.tk_names import EW, HORIZONTAL
 from uiutil import BaseLabelFrame, Button
 from ..window.forwarders import ForwarderConfigWindow
 from ..window.zone import ZoneConfigWindow
 
-logging = logging_helper.setup_logging()
-
 
 class DNSConfigFrame(BaseLabelFrame):
 
