@@ -1,12 +1,9 @@
 # encoding: utf-8
 
-import logging_helper
 from tkinter.constants import NSEW
 from uiutil.window.child import ChildWindow
 from ..frame.forwarder import AddEditForwarderFrame
 
-logging = logging_helper.setup_logging()
-
 
 class AddEditForwarderWindow(ChildWindow):
 
