@@ -1,12 +1,9 @@
 # encoding: utf-8
 
-import logging_helper
 from tkinter.constants import NSEW
 from uiutil.window.child import ChildWindow
 from ..frame.forwarders import ForwarderConfigFrame
 
-logging = logging_helper.setup_logging()
-
 
 class ForwarderConfigWindow(ChildWindow):
 
