@@ -1,6 +1,5 @@
 # encoding: utf-8
 
-import logging_helper
 from uiutil.tk_names import EW
 from uiutil.helper.layout import nice_grid
 from uiutil import RootWindow, ChildWindow
@@ -9,8 +8,6 @@ from classutils.decorators import profiling
 from ...dns_server import DNSServer
 from ..frame.server import DNSServerFrame
 
-logging = logging_helper.setup_logging()
-
 
 class _DNSServerWindow(object):
 
